@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -21,12 +23,15 @@ General-purpose decorators for use with Horizon.
 """
 import functools
 
-from django.utils.translation import gettext_lazy as _
+from django.utils.decorators import available_attrs
+from django.utils.translation import ugettext as _
+
+from horizon.exceptions import NotAuthorized, NotAuthenticated
 
 
 def _current_component(view_func, dashboard=None, panel=None):
-    """Sets the currently-active dashboard and/or panel on the request."""
-    @functools.wraps(view_func, assigned=functools.WRAPPER_ASSIGNMENTS)
+    """ Sets the currently-active dashboard and/or panel on the request. """
+    @functools.wraps(view_func, assigned=available_attrs(view_func))
     def dec(request, *args, **kwargs):
         if dashboard:
             request.horizon['dashboard'] = dashboard
@@ -37,24 +42,23 @@ def _current_component(view_func, dashboard=None, panel=None):
 
 
 def require_auth(view_func):
-    """Performs user authentication check.
+    """ Performs user authentication check.
 
     Similar to Django's `login_required` decorator, except that this throws
     :exc:`~horizon.exceptions.NotAuthenticated` exception if the user is not
     signed-in.
     """
-    from horizon.exceptions import NotAuthenticated
 
-    @functools.wraps(view_func, assigned=functools.WRAPPER_ASSIGNMENTS)
+    @functools.wraps(view_func, assigned=available_attrs(view_func))
     def dec(request, *args, **kwargs):
-        if request.user.is_authenticated:
+        if request.user.is_authenticated():
             return view_func(request, *args, **kwargs)
         raise NotAuthenticated(_("Please log in to continue."))
     return dec
 
 
 def require_perms(view_func, required):
-    """Enforces permission-based access controls.
+    """ Enforces permission-based access controls.
 
     :param list required: A tuple of permission names, all of which the request
                           user must possess in order access the decorated view.
@@ -71,14 +75,13 @@ def require_perms(view_func, required):
     Raises a :exc:`~horizon.exceptions.NotAuthorized` exception if the
     requirements are not met.
     """
-    from horizon.exceptions import NotAuthorized
     # We only need to check each permission once for a view, so we'll use a set
     current_perms = getattr(view_func, '_required_perms', set([]))
     view_func._required_perms = current_perms | set(required)
 
-    @functools.wraps(view_func, assigned=functools.WRAPPER_ASSIGNMENTS)
+    @functools.wraps(view_func, assigned=available_attrs(view_func))
     def dec(request, *args, **kwargs):
-        if request.user.is_authenticated:
+        if request.user.is_authenticated():
             if request.user.has_perms(view_func._required_perms):
                 return view_func(request, *args, **kwargs)
         raise NotAuthorized(_("You are not authorized to access %s")
@@ -87,27 +90,5 @@ def require_perms(view_func, required):
     # If we don't have any permissions, just return the original view.
     if required:
         return dec
-    return view_func
-
-
-def require_component_access(view_func, component):
-    """Perform component can_access check to access the view.
-
-    :param component containing the view (panel or dashboard).
-
-    Raises a :exc:`~horizon.exceptions.NotAuthorized` exception if the
-    user cannot access the component containing the view.
-    By example the check of component policy rules will be applied to its
-    views.
-    """
-    from horizon.exceptions import NotAuthorized
-
-    @functools.wraps(view_func, assigned=functools.WRAPPER_ASSIGNMENTS)
-    def dec(request, *args, **kwargs):
-        if not component.can_access({'request': request}):
-            raise NotAuthorized(_("You are not authorized to access %s")
-                                % request.path)
-
-        return view_func(request, *args, **kwargs)
-
-    return dec
+    else:
+        return view_func
